geocode_address_candidates: Geocode an address and retrieve all candidates using the NJOGIS ArcGIS REST API
Description
Geocode an address and retrieve all candidates using the NJOGIS ArcGIS REST API
Usage
geocode_address_candidates(
address = NULL,
address2 = NULL,
address3 = NULL,
city = NULL,
zip = NULL,
max_results = NULL,
crs = 4326
)
Arguments
address
First line of address. Don't use the other address arguments if geocoding a single line address
city
Name of city or municipality
max_results
Max number of address candidates to return
crs
Four digit coordinate reference system code. Defaults to 4326, 3424 and 4269 are also supported
Value
an sf object with geocoded address candidates for a single address
Examples
Run this code# NOT RUN {
geocode_address_candidates(address = "33 Livingston Ave", city = "New Brunswick")
# }
Run the code above in your browser using DataLab